@@ -51,11 +51,11 @@
 #include "xf86VGAarbiter.h"
 #endif
 /* Entity data */
-EntityPtr *xf86Entities = NULL;	/* Bus slots claimed by drivers */
+EntityPtr *xf86Entities = NULL; /* Bus slots claimed by drivers */
 int xf86NumEntities = 0;
 static int xf86EntityPrivateCount = 0;
 
-BusRec primaryBus = { BUS_NONE, { 0 } };
+BusRec primaryBus = { BUS_NONE, {0} };
 
 /**
  * Call the driver's correct probe function.
@@ -73,26 +73,33 @@ BusRec primaryBus = { BUS_NONE, { 0 } };
  * returned.  Otherwise, \c FALSE is returned.
  */
 Bool
-xf86CallDriverProbe( DriverPtr drv, Bool detect_only )
+xf86CallDriverProbe(DriverPtr drv, Bool detect_only)
 {
-    Bool     foundScreen = FALSE;
+    Bool foundScreen = FALSE;
+
+#ifdef XSERVER_PLATFORM_BUS
+    if (drv->platformProbe != NULL) {
+        foundScreen = xf86platformProbeDev(drv);
+    }
+#endif
+
 #ifdef XSERVER_LIBPCIACCESS
-    if (drv->PciProbe != NULL) {
+    if (!foundScreen && (drv->PciProbe != NULL)) {
         if (xf86DoConfigure && xf86DoConfigurePass1) {
             assert(detect_only);
             foundScreen = xf86PciAddMatchingDev(drv);
         }
         else {
-            assert(! detect_only);
+            assert(!detect_only);
             foundScreen = xf86PciProbeDev(drv);
         }
     }
 #endif
     if (!foundScreen && (drv->Probe != NULL)) {
-        xf86Msg( X_WARNING, "Falling back to old probe method for %s\n",
-                             drv->driverName);
-        foundScreen = (*drv->Probe)(drv, (detect_only) ? PROBE_DETECT
-                                    : PROBE_DEFAULT);
+        xf86Msg(X_WARNING, "Falling back to old probe method for %s\n",
+                drv->driverName);
+        foundScreen = (*drv->Probe) (drv, (detect_only) ? PROBE_DETECT
+                                     : PROBE_DEFAULT);
     }
 
     return foundScreen;
@@ -119,13 +126,14 @@ xf86BusConfig(void)
      */
     for (i = 0; i < xf86NumDrivers; i++) {
         xorgHWFlags flags;
+
         if (!xorgHWAccess) {
             if (!xf86DriverList[i]->driverFunc
-            || !xf86DriverList[i]->driverFunc(NULL,
-                             GET_REQUIRED_HW_INTERFACES,
-                              &flags)
-            || NEED_IO_ENABLED(flags))
-            continue;
+                || !xf86DriverList[i]->driverFunc(NULL,
+                                                  GET_REQUIRED_HW_INTERFACES,
+                                                  &flags)
+                || NEED_IO_ENABLED(flags))
+                continue;
         }
 
         xf86CallDriverProbe(xf86DriverList[i], FALSE);
@@ -155,11 +163,13 @@ xf86BusConfig(void)
         for (layout = xf86ConfigLayout.screens; layout->screen != NULL;
              layout++) {
             Bool found = FALSE;
+
             for (j = 0; j < xf86Screens[i]->numEntities; j++) {
 
-                GDevPtr dev = xf86GetDevFromEntity(
-                                xf86Screens[i]->entityList[j],
-                                xf86Screens[i]->entityInstanceList[j]);
+                GDevPtr dev =
+                    xf86GetDevFromEntity(xf86Screens[i]->entityList[j],
+                                         xf86Screens[i]->entityInstanceList[j]);
+
                 if (dev == layout->screen->device) {
                     /* A match has been found */
                     xf86Screens[i]->confScreen = layout->screen;
@@ -167,20 +177,26 @@ xf86BusConfig(void)
                     break;
                 }
             }
-            if (found) break;
+            if (found)
+                break;
         }
         if (layout->screen == NULL) {
             /* No match found */
             xf86Msg(X_ERROR,
-            "Screen %d deleted because of no matching config section.\n", i);
-            xf86DeleteScreen(i--, 0);
+                    "Screen %d deleted because of no matching config section.\n",
+                    i);
+            xf86DeleteScreen(xf86Screens[i--]);
         }
     }
 
+    /* bind GPU conf screen to protocol screen 0 */
+    for (i = 0; i < xf86NumGPUScreens; i++)
+        xf86GPUScreens[i]->confScreen = xf86Screens[0]->confScreen;
+
     /* If no screens left, return now.  */
     if (xf86NumScreens == 0) {
         xf86Msg(X_ERROR,
-        "Device(s) detected, but none match those in the config file.\n");
+                "Device(s) detected, but none match those in the config file.\n");
         return FALSE;
     }
 
@@ -196,6 +212,9 @@ xf86BusConfig(void)
 void
 xf86BusProbe(void)
 {
+#ifdef XSERVER_PLATFORM_BUS
+    xf86platformProbe();
+#endif
 #ifdef XSERVER_LIBPCIACCESS
     xf86PciProbe();
 #endif
@@ -210,31 +229,33 @@ xf86BusProbe(void)
  */
 
 BusType
-StringToBusType(const char* busID, const char **retID)
+StringToBusType(const char *busID, const char **retID)
 {
     char *p, *s;
     BusType ret = BUS_NONE;
 
     /* If no type field, Default to PCI */
     if (isdigit(busID[0])) {
-	if (retID)
-	    *retID = busID;
-	return BUS_PCI;
+        if (retID)
+            *retID = busID;
+        return BUS_PCI;
     }
 
     s = xstrdup(busID);
     p = strtok(s, ":");
     if (p == NULL || *p == 0) {
-	free(s);
-	return BUS_NONE;
+        free(s);
+        return BUS_NONE;
     }
     if (!xf86NameCmp(p, "pci") || !xf86NameCmp(p, "agp"))
-	ret = BUS_PCI; 
+        ret = BUS_PCI;
     if (!xf86NameCmp(p, "sbus"))
-	ret = BUS_SBUS;
+        ret = BUS_SBUS;
+    if (!xf86NameCmp(p, "platform"))
+        ret = BUS_PLATFORM;
     if (ret != BUS_NONE)
-	if (retID)
-	    *retID = busID + strlen(p) + 1;
+        if (retID)
+            *retID = busID + strlen(p) + 1;
     free(s);
     return ret;
 }
@@ -244,10 +265,10 @@ xf86AllocateEntity(void)
 {
     xf86NumEntities++;
     xf86Entities = xnfrealloc(xf86Entities,
-			      sizeof(EntityPtr) * xf86NumEntities);
-    xf86Entities[xf86NumEntities - 1] = xnfcalloc(1,sizeof(EntityRec));
+                              sizeof(EntityPtr) * xf86NumEntities);
+    xf86Entities[xf86NumEntities - 1] = xnfcalloc(1, sizeof(EntityRec));
     xf86Entities[xf86NumEntities - 1]->entityPrivates =
-               xnfcalloc(sizeof(DevUnion) * xf86EntityPrivateCount, 1);
+        xnfcalloc(sizeof(DevUnion) * xf86EntityPrivateCount, 1);
     return xf86NumEntities - 1;
 }
 
@@ -255,25 +276,28 @@ Bool
 xf86IsEntityPrimary(int entityIndex)
 {
     EntityPtr pEnt = xf86Entities[entityIndex];
-    
-    if (primaryBus.type != pEnt->bus.type) return FALSE;
+
+    if (primaryBus.type != pEnt->bus.type)
+        return FALSE;
 
     switch (pEnt->bus.type) {
     case BUS_PCI:
-	return pEnt->bus.id.pci == primaryBus.id.pci;
+        return pEnt->bus.id.pci == primaryBus.id.pci;
     case BUS_SBUS:
-	return pEnt->bus.id.sbus.fbNum == primaryBus.id.sbus.fbNum;
+        return pEnt->bus.id.sbus.fbNum == primaryBus.id.sbus.fbNum;
+    case BUS_PLATFORM:
+        return pEnt->bus.id.plat == primaryBus.id.plat;
     default:
-	return FALSE;
+        return FALSE;
     }
 }
-	
+
 Bool
 xf86SetEntityFuncs(int entityIndex, EntityProc init, EntityProc enter,
-		   EntityProc leave, pointer private)
+                   EntityProc leave, pointer private)
 {
     if (entityIndex >= xf86NumEntities)
-	return FALSE;
+        return FALSE;
     xf86Entities[entityIndex]->entityInit = init;
     xf86Entities[entityIndex]->entityEnter = enter;
     xf86Entities[entityIndex]->entityLeave = leave;
@@ -285,9 +309,10 @@ Bool
 xf86DriverHasEntities(DriverPtr drvp)
 {
     int i;
+
     for (i = 0; i < xf86NumEntities; i++) {
-	if (xf86Entities[i]->driver == drvp) 
-	    return TRUE;
+        if (xf86Entities[i]->driver == drvp)
+            return TRUE;
     }
     return FALSE;
 }
@@ -296,20 +321,20 @@ void
 xf86AddEntityToScreen(ScrnInfoPtr pScrn, int entityIndex)
 {
     if (entityIndex == -1)
-	return;
+        return;
     if (xf86Entities[entityIndex]->inUse &&
-	!(xf86Entities[entityIndex]->entityProp & IS_SHARED_ACCEL)) {
-	ErrorF("Requested Entity already in use!\n");
-	return;
+        !(xf86Entities[entityIndex]->entityProp & IS_SHARED_ACCEL)) {
+        ErrorF("Requested Entity already in use!\n");
+        return;
     }
 
     pScrn->numEntities++;
     pScrn->entityList = xnfrealloc(pScrn->entityList,
-				    pScrn->numEntities * sizeof(int));
+                                   pScrn->numEntities * sizeof(int));
     pScrn->entityList[pScrn->numEntities - 1] = entityIndex;
     xf86Entities[entityIndex]->inUse = TRUE;
     pScrn->entityInstanceList = xnfrealloc(pScrn->entityInstanceList,
-				    pScrn->numEntities * sizeof(int));
+                                           pScrn->numEntities * sizeof(int));
     pScrn->entityInstanceList[pScrn->numEntities - 1] = 0;
 }
 
@@ -319,13 +344,13 @@ xf86SetEntityInstanceForScreen(ScrnInfoPtr pScrn, int entityIndex, int instance)
     int i;
 
     if (entityIndex == -1 || entityIndex >= xf86NumEntities)
-	return;
+        return;
 
     for (i = 0; i < pScrn->numEntities; i++) {
-	if (pScrn->entityList[i] == entityIndex) {
-	    pScrn->entityInstanceList[i] = instance;
-	    break;
-	}
+        if (pScrn->entityList[i] == entityIndex) {
+            pScrn->entityInstanceList[i] = instance;
+            break;
+        }
     }
 }
 
@@ -336,17 +361,18 @@ xf86SetEntityInstanceForScreen(ScrnInfoPtr pScrn, int entityIndex, int instance)
 ScrnInfoPtr
 xf86FindScreenForEntity(int entityIndex)
 {
-    int i,j;
+    int i, j;
+
+    if (entityIndex == -1)
+        return NULL;
 
-    if (entityIndex == -1) return NULL;
-    
     if (xf86Screens) {
-	for (i = 0; i < xf86NumScreens; i++) {
-	    for (j = 0; j < xf86Screens[i]->numEntities; j++) {
-		if ( xf86Screens[i]->entityList[j] == entityIndex )
-		    return xf86Screens[i];
-	    }
-	}
+        for (i = 0; i < xf86NumScreens; i++) {
+            for (j = 0; j < xf86Screens[i]->numEntities; j++) {
+                if (xf86Screens[i]->entityList[j] == entityIndex)
+                    return xf86Screens[i];
+            }
+        }
     }
     return NULL;
 }
@@ -355,34 +381,34 @@ void
 xf86RemoveEntityFromScreen(ScrnInfoPtr pScrn, int entityIndex)
 {
     int i;
-    
+
     for (i = 0; i < pScrn->numEntities; i++) {
-	if (pScrn->entityList[i] == entityIndex) {
-	    for (i++; i < pScrn->numEntities; i++)
-		pScrn->entityList[i-1] = pScrn->entityList[i];
-	    pScrn->numEntities--;
-	    xf86Entities[entityIndex]->inUse = FALSE;
-	    break;
-	}
+        if (pScrn->entityList[i] == entityIndex) {
+            for (i++; i < pScrn->numEntities; i++)
+                pScrn->entityList[i - 1] = pScrn->entityList[i];
+            pScrn->numEntities--;
+            xf86Entities[entityIndex]->inUse = FALSE;
+            break;
+        }
     }
 }
 
 /*
- * xf86ClearEntitiesForScreen() - called when a screen is deleted
+ * xf86ClearEntityListForScreen() - called when a screen is deleted
  * to mark it's entities unused. Called by xf86DeleteScreen().
  */
 void
-xf86ClearEntityListForScreen(int scrnIndex)
+xf86ClearEntityListForScreen(ScrnInfoPtr pScrn)
 {
-    ScrnInfoPtr pScrn = xf86Screens[scrnIndex];
     int i, entityIndex;
-    
-    if (pScrn->entityList == NULL || pScrn->numEntities == 0) return;
-	
+
+    if (pScrn->entityList == NULL || pScrn->numEntities == 0)
+        return;
+
     for (i = 0; i < pScrn->numEntities; i++) {
-	entityIndex = pScrn->entityList[i];
-	xf86Entities[entityIndex]->inUse = FALSE;
-	/* disable resource: call the disable function */
+        entityIndex = pScrn->entityList[i];
+        xf86Entities[entityIndex]->inUse = FALSE;
+        /* disable resource: call the disable function */
     }
     free(pScrn->entityList);
     free(pScrn->entityInstanceList);
@@ -398,18 +424,38 @@ void
 xf86AddDevToEntity(int entityIndex, GDevPtr dev)
 {
     EntityPtr pEnt;
-    
+
     if (entityIndex >= xf86NumEntities)
-	return;
-    
+        return;
+
     pEnt = xf86Entities[entityIndex];
     pEnt->numInstances++;
     pEnt->devices = xnfrealloc(pEnt->devices,
-				pEnt->numInstances * sizeof(GDevPtr));
+                               pEnt->numInstances * sizeof(GDevPtr));
     pEnt->devices[pEnt->numInstances - 1] = dev;
     dev->claimed = TRUE;
 }
 
+
+void
+xf86RemoveDevFromEntity(int entityIndex, GDevPtr dev)
+{
+    EntityPtr pEnt;
+    int i, j;
+    if (entityIndex >= xf86NumEntities)
+        return;
+
+    pEnt = xf86Entities[entityIndex];
+    for (i = 0; i < pEnt->numInstances; i++) {
+        if (pEnt->devices[i] == dev) {
+            for (j = i; j < pEnt->numInstances - 1; j++)
+                pEnt->devices[j] = pEnt->devices[j + 1];
+            break;
+        }
+    }
+    pEnt->numInstances--;
+    dev->claimed = FALSE;
+}
 /*
  * xf86GetEntityInfo() -- This function hands information from the
  * EntityRec struct to the drivers. The EntityRec structure itself
@@ -420,28 +466,29 @@ xf86GetEntityInfo(int entityIndex)
 {
     EntityInfoPtr pEnt;
     int i;
-    
+
     if (entityIndex == -1)
-	return NULL;
+        return NULL;
 
     if (entityIndex >= xf86NumEntities)
-	return NULL;
-    
-    pEnt = xnfcalloc(1,sizeof(EntityInfoRec));
+        return NULL;
+
+    pEnt = xnfcalloc(1, sizeof(EntityInfoRec));
     pEnt->index = entityIndex;
     pEnt->location = xf86Entities[entityIndex]->bus;
     pEnt->active = xf86Entities[entityIndex]->active;
     pEnt->chipset = xf86Entities[entityIndex]->chipset;
     pEnt->driver = xf86Entities[entityIndex]->driver;
-    if ( (xf86Entities[entityIndex]->devices) &&
-         (xf86Entities[entityIndex]->devices[0]) ) {
-	for (i = 0; i < xf86Entities[entityIndex]->numInstances; i++)
-	    if (xf86Entities[entityIndex]->devices[i]->screen == 0)
-	        break;
-	pEnt->device = xf86Entities[entityIndex]->devices[i];
-    } else
-	pEnt->device = NULL;
-    
+    if ((xf86Entities[entityIndex]->devices) &&
+        (xf86Entities[entityIndex]->devices[0])) {
+        for (i = 0; i < xf86Entities[entityIndex]->numInstances; i++)
+            if (xf86Entities[entityIndex]->devices[i]->screen == 0)
+                break;
+        pEnt->device = xf86Entities[entityIndex]->devices[i];
+    }
+    else
+        pEnt->device = NULL;
+
     return pEnt;
 }
 
@@ -449,8 +496,8 @@ int
 xf86GetNumEntityInstances(int entityIndex)
 {
     if (entityIndex >= xf86NumEntities)
-	return -1;
-    
+        return -1;
+
     return xf86Entities[entityIndex]->numInstances;
 }
 
@@ -458,19 +505,19 @@ GDevPtr
 xf86GetDevFromEntity(int entityIndex, int instance)
 {
     int i;
-  
+
     /* We might not use AddDevtoEntity */
-    if ( (!xf86Entities[entityIndex]->devices) ||
-         (!xf86Entities[entityIndex]->devices[0]) ) 
-	return NULL;
+    if ((!xf86Entities[entityIndex]->devices) ||
+        (!xf86Entities[entityIndex]->devices[0]))
+        return NULL;
 
     if (entityIndex >= xf86NumEntities ||
-	instance >= xf86Entities[entityIndex]->numInstances)
-	return NULL;
-    
+        instance >= xf86Entities[entityIndex]->numInstances)
+        return NULL;
+
     for (i = 0; i < xf86Entities[entityIndex]->numInstances; i++)
-	if (xf86Entities[entityIndex]->devices[i]->screen == instance)
-	    break;
+        if (xf86Entities[entityIndex]->devices[i]->screen == instance)
+            break;
     return xf86Entities[entityIndex]->devices[i];
 }
 
@@ -485,7 +532,7 @@ xf86AccessEnter(void)
 
     for (i = 0; i < xf86NumEntities; i++)
         if (xf86Entities[i]->entityEnter)
-		xf86Entities[i]->entityEnter(i,xf86Entities[i]->private);
+            xf86Entities[i]->entityEnter(i, xf86Entities[i]->private);
 }
 
 void
@@ -495,7 +542,7 @@ xf86AccessLeave(void)
 
     for (i = 0; i < xf86NumEntities; i++)
         if (xf86Entities[i]->entityLeave)
-		xf86Entities[i]->entityLeave(i,xf86Entities[i]->private);
+            xf86Entities[i]->entityLeave(i, xf86Entities[i]->private);
 }
 
 /*
@@ -509,28 +556,32 @@ xf86PostProbe(void)
 
     if (fbSlotClaimed && (
 #if (defined(__sparc__) || defined(__sparc)) && !defined(__OpenBSD__)
-	    sbusSlotClaimed ||
+                             sbusSlotClaimed ||
+#endif
+#ifdef XSERVER_PLATFORM_BUS
+                             platformSlotClaimed ||
 #endif
 #ifdef XSERVER_LIBPCIACCESS
-	    pciSlotClaimed
+                             pciSlotClaimed
 #else
-        TRUE
+                             TRUE
 #endif
-	    ))
-	    FatalError("Cannot run in framebuffer mode. Please specify busIDs "
-		       "       for all framebuffer devices\n");
+        ))
+        FatalError("Cannot run in framebuffer mode. Please specify busIDs "
+                   "       for all framebuffer devices\n");
 
     for (i = 0; i < xf86NumEntities; i++)
         if (xf86Entities[i]->entityInit)
-	    xf86Entities[i]->entityInit(i,xf86Entities[i]->private);
+            xf86Entities[i]->entityInit(i, xf86Entities[i]->private);
 }
 
 int
 xf86GetLastScrnFlag(int entityIndex)
 {
-    if(entityIndex < xf86NumEntities) {
+    if (entityIndex < xf86NumEntities) {
         return xf86Entities[entityIndex]->lastScrnFlag;
-    } else {
+    }
+    else {
         return -1;
     }
 }
@@ -538,7 +589,7 @@ xf86GetLastScrnFlag(int entityIndex)
 void
 xf86SetLastScrnFlag(int entityIndex, int scrnIndex)
 {
-    if(entityIndex < xf86NumEntities) {
+    if (entityIndex < xf86NumEntities) {
         xf86Entities[entityIndex]->lastScrnFlag = scrnIndex;
     }
 }
@@ -546,10 +597,10 @@ xf86SetLastScrnFlag(int entityIndex, int scrnIndex)
 Bool
 xf86IsEntityShared(int entityIndex)
 {
-    if(entityIndex < xf86NumEntities) {
-        if(xf86Entities[entityIndex]->entityProp & IS_SHARED_ACCEL) {
-	    return TRUE;
-	}
+    if (entityIndex < xf86NumEntities) {
+        if (xf86Entities[entityIndex]->entityProp & IS_SHARED_ACCEL) {
+            return TRUE;
+        }
     }
     return FALSE;
 }
@@ -557,7 +608,7 @@ xf86IsEntityShared(int entityIndex)
 void
 xf86SetEntityShared(int entityIndex)
 {
-    if(entityIndex < xf86NumEntities) {
+    if (entityIndex < xf86NumEntities) {
         xf86Entities[entityIndex]->entityProp |= IS_SHARED_ACCEL;
     }
 }
@@ -565,10 +616,10 @@ xf86SetEntityShared(int entityIndex)
 Bool
 xf86IsEntitySharable(int entityIndex)
 {
-    if(entityIndex < xf86NumEntities) {
-        if(xf86Entities[entityIndex]->entityProp & ACCEL_IS_SHARABLE) {
-	    return TRUE;
-	}
+    if (entityIndex < xf86NumEntities) {
+        if (xf86Entities[entityIndex]->entityProp & ACCEL_IS_SHARABLE) {
+            return TRUE;
+        }
     }
     return FALSE;
 }
@@ -576,7 +627,7 @@ xf86IsEntitySharable(int entityIndex)
 void
 xf86SetEntitySharable(int entityIndex)
 {
-    if(entityIndex < xf86NumEntities) {
+    if (entityIndex < xf86NumEntities) {
         xf86Entities[entityIndex]->entityProp |= ACCEL_IS_SHARABLE;
     }
 }
@@ -584,10 +635,10 @@ xf86SetEntitySharable(int entityIndex)
 Bool
 xf86IsPrimInitDone(int entityIndex)
 {
-    if(entityIndex < xf86NumEntities) {
-        if(xf86Entities[entityIndex]->entityProp & SA_PRIM_INIT_DONE) {
-	    return TRUE;
-	}
+    if (entityIndex < xf86NumEntities) {
+        if (xf86Entities[entityIndex]->entityProp & SA_PRIM_INIT_DONE) {
+            return TRUE;
+        }
     }
     return FALSE;
 }
@@ -595,7 +646,7 @@ xf86IsPrimInitDone(int entityIndex)
 void
 xf86SetPrimInitDone(int entityIndex)
 {
-    if(entityIndex < xf86NumEntities) {
+    if (entityIndex < xf86NumEntities) {
         xf86Entities[entityIndex]->entityProp |= SA_PRIM_INIT_DONE;
     }
 }
@@ -603,12 +654,11 @@ xf86SetPrimInitDone(int entityIndex)
 void
 xf86ClearPrimInitDone(int entityIndex)
 {
-    if(entityIndex < xf86NumEntities) {
+    if (entityIndex < xf86NumEntities) {
         xf86Entities[entityIndex]->entityProp &= ~SA_PRIM_INIT_DONE;
     }
 }
 
-
 /*
  * Allocate a private in the entities.
  */
@@ -622,12 +672,12 @@ xf86AllocateEntityPrivateIndex(void)
 
     idx = xf86EntityPrivateCount++;
     for (i = 0; i < xf86NumEntities; i++) {
-	pEnt = xf86Entities[i];
-	nprivs = xnfrealloc(pEnt->entityPrivates,
-			    xf86EntityPrivateCount * sizeof(DevUnion));
-	/* Zero the new private */
-	memset(&nprivs[idx], 0, sizeof(DevUnion));
-	pEnt->entityPrivates = nprivs;
+        pEnt = xf86Entities[i];
+        nprivs = xnfrealloc(pEnt->entityPrivates,
+                            xf86EntityPrivateCount * sizeof(DevUnion));
+        /* Zero the new private */
+        memset(&nprivs[idx], 0, sizeof(DevUnion));
+        pEnt->entityPrivates = nprivs;
     }
     return idx;
 }
@@ -636,8 +686,7 @@ DevUnion *
 xf86GetEntityPrivate(int entityIndex, int privIndex)
 {
     if (entityIndex >= xf86NumEntities || privIndex >= xf86EntityPrivateCount)
-	return NULL;
+        return NULL;
 
     return &(xf86Entities[entityIndex]->entityPrivates[privIndex]);
 }
-
